@@ -1,8 +1,11 @@
-"""FEM implementation
+"""FEM implementation for N dimensional and M variables per node.
+
 """
+__author__ = "Arturo Rodriguez - da.rodriguezh@uniandes.edu.co"
 
 from .__version__ import __version__
 from .Elements import *
+from .Mesh import *
 from .Core import *
 from .Torsion2D import *
 from .EDO1D import *
@@ -10,8 +13,4 @@ from .EulerBernoulliBeam import *
 from .PlaneStress import *
 from .PlaneStressNonLocal import *
 from .PlaneStrain import *
-
-__author__ = "Arturo Rodriguez - da.rodriguezh@uniandes.edu.co"
-
-__all__ = ["Elements", "Core", "Torsion2D", "EDO1D", "EulerBernoulliBeam",
-           "PlaneStress", "PlaneStrain", "PlaneStressNonLocal", "Mesh"]
+from .Heat1D import *
